==> vst3sdk-docs-3.7.8_build_34-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstinterfaces/ivstchannelcontextinfo_8h.js <==
var ivstchannelcontextinfo_8h =
[
    [ "IInfoListener", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener" ],
    [ "ColorSpec", "ivstchannelcontextinfo_8h.html#ga5b13d028fba1eee386ec9ac208c6238d", null ],
    [ "ColorComponent", "ivstchannelcontextinfo_8h.html#gaf1189c83b63820c6ccc3167402601fea", null ],
    [ "ChannelPluginLocation", "ivstchannelcontextinfo_8h.html#ac6ac8886bd59deb9f997179931a168af", [
      [ "kPreVolumeFader", "ivstchannelcontextinfo_8h.html#ac6ac8886bd59deb9f997179931a168afa21f636e119b96f85db893e981c6d0fbb", null ],
      [ "kPostVolumeFader", "ivstchannelcontextinfo_8h.html#ac6ac8886bd59deb9f997179931a168afa352f87b06111d7eb4502ca8884ba1bfb", null ],
      [ "kUsedAsPanner", "ivstchannelcontextinfo_8h.html#ac6ac8886bd59deb9f997179931a168afab4d561ce249fb47b1411e92455468810", null ]
    ] ],
    [ "GetBlue", "ivstchannelcontextinfo_8h.html#a641c048e19cbdf7b753446f6e06b92e9", null ],
    [ "GetGreen", "ivstchannelcontextinfo_8h.html#a85a872d79e8879f75593a51a62e3c61b", null ],
    [ "GetRed", "ivstchannelcontextinfo_8h.html#a0631a9689c90dab1e9267681bc3d351a", null ],
    [ "GetAlpha", "ivstchannelcontextinfo_8h.html#a59f0bbea32d4ae966062be29a76bd969", null ],
    [ "kChannelUIDKey", "ivstchannelcontextinfo_8h.html#a68ad60e2a9bdcefda0e2296e7f9296f9", null ],
    [ "kChannelUIDLengthKey", "ivstchannelcontextinfo_8h.html#af44825ca23e7c673682f438d8cf6283e", null ],
    [ "kChannelNameKey", "ivstchannelcontextinfo_8h.html#a355d0e3fe55ba9c58ebe6cb29cf27ce5", null ],
    [ "kChannelNameLengthKey", "ivstchannelcontextinfo_8h.html#a175778add2bfeafd5b184f4e47869e80", null ],
    [ "kChannelColorKey", "ivstchannelcontextinfo_8h.html#a218d5777a06f7780c7ded2a14c9f2922", null ],
    [ "kChannelIndexKey", "ivstchannelcontextinfo_8h.html#a42930b877ebbb27bf3daa78d02780be1", null ],
    [ "kChannelIndexNamespaceOrderKey", "ivstchannelcontextinfo_8h.html#acd822b1c74f9c7e9afaa16b0ce578f7e", null ],
    [ "kChannelIndexNamespaceKey", "ivstchannelcontextinfo_8h.html#a9dee889cb7b726bf9bf9f21c79334261", null ],
    [ "kChannelIndexNamespaceLengthKey", "ivstchannelcontextinfo_8h.html#a9b082b198abef61a8397bafcf4e30a72", null ],
    [ "kChannelImageKey", "ivstchannelcontextinfo_8h.html#a6ba9324db0a3f814e6f41df444e0f7e7", null ],
    [ "kChannelPluginLocationKey", "ivstchannelcontextinfo_8h.html#a1836e6445deeff80efc1d389b8ba7ac5", null ]
];

==> vst3sdk-docs-3.7.12_build_20-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstinterfaces/ivstchannelcontextinfo_8h.js <==
var ivstchannelcontextinfo_8h =
[
    [ "IInfoListener", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener.html", "classSteinberg_1_1Vst_1_1ChannelContext_1_1IInfoListener" ],
    [ "ColorSpec", "ivstchannelcontextinfo_8h.html#a5b13d028fba1eee386ec9ac208c6238d", null ],
    [ "ColorComponent", "ivstchannelcontextinfo_8h.html#af1189c83b63820c6ccc3167402601fea", null ],
    [ "ChannelPluginLocation", "ivstchannelcontextinfo_8h.html#ac6ac8886bd59deb9f997179931a168af", [
      [ "kPreVolumeFader", "ivstchannelcontextinfo_8h.html#ac6ac8886bd59deb9f997179931a168afa21f636e119b96f85db893e981c6d0fbb", null ],
      [ "kPostVolumeFader", "ivstchannelcontextinfo_8h.html#ac6ac8886bd59deb9f997179931a168afa352f87b06111d7eb4502ca8884ba1bfb", null ],
      [ "kUsedAsPanner", "ivstchannelcontextinfo_8h.html#ac6ac8886bd59deb9f997179931a168afab4d561ce249fb47b1411e92455468810", null ]
    ] ],
    [ "GetBlue", "ivstchannelcontextinfo_8h.html#a641c048e19cbdf7b753446f6e06b92e9", null ],
    [ "GetGreen", "ivstchannelcontextinfo_8h.html#a85a872d79e8879f75593a51a62e3c61b", null ],
    [ "GetRed", "ivstchannelcontextinfo_8h.html#a0631a9689c90dab1e9267681bc3d351a", null ],
    [ "GetAlpha", "ivstchannelcontextinfo_8h.html#a59f0bbea32d4ae966062be29a76bd969", null ],
    [ "kChannelUIDKey", "ivstchannelcontextinfo_8h.html#a68ad60e2a9bdcefda0e2296e7f9296f9", null ],
    [ "kChannelUIDLengthKey", "ivstchannelcontextinfo_8h.html#af44825ca23e7c673682f438d8cf6283e", null ],
    [ "kChannelNameKey", "ivstchannelcontextinfo_8h.html#a355d0e3fe55ba9c58ebe6cb29cf27ce5", null ],
    [ "kChannelNameLengthKey", "ivstchannelcontextinfo_8h.html#a175778add2bfeafd5b184f4e47869e80", null ],
    [ "kChannelColorKey", "ivstchannelcontextinfo_8h.html#a218d5777a06f7780c7ded2a14c9f2922", null ],
    [ "kChannelIndexKey", "ivstchannelcontextinfo_8h.html#a42930b877ebbb27bf3daa78d02780be1", null ],
    [ "kChannelIndexNamespaceOrderKey", "ivstchannelcontextinfo_8h.html#acd822b1c74f9c7e9afaa16b0ce578f7e", null ],
    [ "kChannelIndexNamespaceKey", "ivstchannelcontextinfo_8h.html#a9dee889cb7b726bf9bf9f21c79334261", null ],
    [ "kChannelIndexNamespaceLengthKey", "ivstchannelcontextinfo_8h.html#a9b082b198abef61a8397bafcf4e30a72", null ],
    [ "kChannelImageKey", "ivstchannelcontextinfo_8h.html#a6ba9324db0a3f814e6f41df444e0f7e7", null ],
    [ "kChannelPluginLocationKey", "ivstchannelcontextinfo_8h.html#a1836e6445deeff80efc1d389b8ba7ac5", null ]
];
